EXPORTS
	?CancelConnect@CBTEngConnMan@@QAEXABVTBTDevAddr@@@Z @ 1 NONAME ; void CBTEngConnMan::CancelConnect(class TBTDevAddr const &)
	?CancelPairDevice@CBTEngConnMan@@QAEXXZ @ 2 NONAME ; void CBTEngConnMan::CancelPairDevice(void)
	?Connect@CBTEngConnMan@@QAEHABVTBTDevAddr@@ABVTBTDeviceClass@@@Z @ 3 NONAME ; int CBTEngConnMan::Connect(class TBTDevAddr const &, class TBTDeviceClass const &)
	?Disconnect@CBTEngConnMan@@QAEHABVTBTDevAddr@@W4TBTDisconnectType@@@Z @ 4 NONAME ; int CBTEngConnMan::Disconnect(class TBTDevAddr const &, enum TBTDisconnectType)
	?GetConnectedAddresses@CBTEngConnMan@@QAEHAAV?$RArray@VTBTDevAddr@@@@@Z @ 5 NONAME ; int CBTEngConnMan::GetConnectedAddresses(class RArray<class TBTDevAddr> &)
	?GetConnectedAddresses@CBTEngConnMan@@QAEHAAV?$RArray@VTBTDevAddr@@@@W4TBTProfile@@@Z @ 6 NONAME ; int CBTEngConnMan::GetConnectedAddresses(class RArray<class TBTDevAddr> &, enum TBTProfile)
	?IsConnectable@CBTEngConnMan@@QAEHABVTBTDeviceClass@@AAH@Z @ 7 NONAME ; int CBTEngConnMan::IsConnectable(class TBTDeviceClass const &, int &)
	?IsConnected@CBTEngConnMan@@QAEHABVTBTDevAddr@@AAW4TBTEngConnectionStatus@@@Z @ 8 NONAME ; int CBTEngConnMan::IsConnected(class TBTDevAddr const &, enum TBTEngConnectionStatus &)
	?NewL@CBTEngConnMan@@SAPAV1@PAVMBTEngConnObserver@@@Z @ 9 NONAME ; class CBTEngConnMan * CBTEngConnMan::NewL(class MBTEngConnObserver *)
	?NewLC@CBTEngConnMan@@SAPAV1@PAVMBTEngConnObserver@@@Z @ 10 NONAME ; class CBTEngConnMan * CBTEngConnMan::NewLC(class MBTEngConnObserver *)
	?PairDevice@CBTEngConnMan@@QAEHABVTBTDevAddr@@@Z @ 11 NONAME ; int CBTEngConnMan::PairDevice(class TBTDevAddr const &)
	?PairingComplete@MBTEngConnObserver@@UAEXAAVTBTDevAddr@@H@Z @ 12 NONAME ; void MBTEngConnObserver::PairingComplete(class TBTDevAddr &, int)
	?PrepareDiscovery@CBTEngConnMan@@QAEXXZ @ 13 NONAME ; void CBTEngConnMan::PrepareDiscovery(void)
	?RemoveObserver@CBTEngConnMan@@QAEXXZ @ 14 NONAME ; void CBTEngConnMan::RemoveObserver(void)
	?SetObserver@CBTEngConnMan@@QAEHPAVMBTEngConnObserver@@@Z @ 15 NONAME ; int CBTEngConnMan::SetObserver(class MBTEngConnObserver *)
	?StartPairingObserver@CBTEngConnMan@@SAHABVTBTDevAddr@@@Z @ 16 NONAME ; int CBTEngConnMan::StartPairingObserver(class TBTDevAddr const &)
	?PairDevice@CBTEngConnMan@@QAEHABVTBTDevAddr@@VTBTDeviceClass@@@Z @ 17 NONAME ; int CBTEngConnMan::PairDevice(class TBTDevAddr const &, class TBTDeviceClass)
	?IsConnectable@CBTEngConnMan@@QAEHABVTBTDevAddr@@ABVTBTDeviceClass@@AAH@Z @ 18 NONAME ; int CBTEngConnMan::IsConnectable(class TBTDevAddr const &, class TBTDeviceClass const &, int &)
	?StopPairingObserver@CBTEngConnMan@@SAHABVTBTDevAddr@@@Z @ 19 NONAME ; int CBTEngConnMan::StopPairingObserver(class TBTDevAddr const &)

